==> knative-model-4.10.1-sources.jar: io/fabric8/knative/flows/v1alpha1/SequenceStepFluent.java <==
package io.fabric8.knative.flows.v1alpha1;

import io.fabric8.knative.dev.duck.v1beta1.DeliverySpecFluent;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.duck.v1.KReference;
import io.fabric8.knative.duck.v1.KReferenceFluent;
import java.lang.StringBuffer;
import io.fabric8.knative.dev.duck.v1beta1.DeliverySpecBuilder;
import java.lang.Deprecated;
import io.fabric8.knative.duck.v1.KReferenceBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.knative.dev.duck.v1beta1.DeliverySpec;

public interface SequenceStepFluent<A extends SequenceStepFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDelivery instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public DeliverySpec getDelivery();
    public DeliverySpec buildDelivery();
    public A withDelivery(DeliverySpec delivery);
    public Boolean hasDelivery();
    public SequenceStepFluent.DeliveryNested<A> withNewDelivery();
    public SequenceStepFluent.DeliveryNested<A> withNewDeliveryLike(DeliverySpec item);
    public SequenceStepFluent.DeliveryNested<A> editDelivery();
    public SequenceStepFluent.DeliveryNested<A> editOrNewDelivery();
    public SequenceStepFluent.DeliveryNested<A> editOrNewDeliveryLike(DeliverySpec item);
    
/**
 * This method has been deprecated, please use method buildRef instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public KReference getRef();
    public KReference buildRef();
    public A withRef(KReference ref);
    public Boolean hasRef();
    public A withNewRef(String apiVersion,String kind,String name,String namespace);
    public SequenceStepFluent.RefNested<A> withNewRef();
    public SequenceStepFluent.RefNested<A> withNewRefLike(KReference item);
    public SequenceStepFluent.RefNested<A> editRef();
    public SequenceStepFluent.RefNested<A> editOrNewRef();
    public SequenceStepFluent.RefNested<A> editOrNewRefLike(KReference item);
    public String getUri();
    public A withUri(String uri);
    public Boolean hasUri();
    public A withNewUri(String arg1);
    public A withNewUri(StringBuilder arg1);
    public A withNewUri(StringBuffer arg1);

    public interface DeliveryNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeliverySpecFluent<SequenceStepFluent.DeliveryNested<N>>{

        
    public N and();    public N endDelivery();
}
    public interface RefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KReferenceFluent<SequenceStepFluent.RefNested<N>>{

        
    public N and();    public N endRef();
}


}

==> knative-model-4.11.2-sources.jar: io/fabric8/knative/flows/v1alpha1/SequenceStepFluent.java <==
package io.fabric8.knative.flows.v1alpha1;

import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1beta1.DeliverySpecFluent;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReference;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceFluent;
import java.lang.StringBuffer;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1beta1.DeliverySpecBuilder;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1beta1.DeliverySpec;

public interface SequenceStepFluent<A extends SequenceStepFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDelivery instead.
 * @return The buildable object.
 */
@Deprecated public DeliverySpec getDelivery();
    public DeliverySpec buildDelivery();
    public A withDelivery(DeliverySpec delivery);
    public Boolean hasDelivery();
    public SequenceStepFluent.DeliveryNested<A> withNewDelivery();
    public SequenceStepFluent.DeliveryNested<A> withNewDeliveryLike(DeliverySpec item);
    public SequenceStepFluent.DeliveryNested<A> editDelivery();
    public SequenceStepFluent.DeliveryNested<A> editOrNewDelivery();
    public SequenceStepFluent.DeliveryNested<A> editOrNewDeliveryLike(DeliverySpec item);
    
/**
 * This method has been deprecated, please use method buildRef instead.
 * @return The buildable object.
 */
@Deprecated public KReference getRef();
    public KReference buildRef();
    public A withRef(KReference ref);
    public Boolean hasRef();
    public A withNewRef(String apiVersion,String kind,String name,String namespace);
    public SequenceStepFluent.RefNested<A> withNewRef();
    public SequenceStepFluent.RefNested<A> withNewRefLike(KReference item);
    public SequenceStepFluent.RefNested<A> editRef();
    public SequenceStepFluent.RefNested<A> editOrNewRef();
    public SequenceStepFluent.RefNested<A> editOrNewRefLike(KReference item);
    public String getUri();
    public A withUri(String uri);
    public Boolean hasUri();
    public A withNewUri(String arg1);
    public A withNewUri(StringBuilder arg1);
    public A withNewUri(StringBuffer arg1);

    public interface DeliveryNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeliverySpecFluent<SequenceStepFluent.DeliveryNested<N>>{

        
    public N and();    public N endDelivery();
}
    public interface RefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KReferenceFluent<SequenceStepFluent.RefNested<N>>{

        
    public N and();    public N endRef();
}


}
